@@ -49,7 +49,7 @@ class Reference(HasTraits):
     def check(self, d):
         """validate a dict against our traits"""
         for key in self.trait_names():
-            nt.assert_in(key, d)
+            assert key in d
             # FIXME: always allow None, probably not a good idea
             if d[key] is None:
                 continue
@@ -101,7 +101,7 @@ class MimeBundle(Reference):
     def _data_changed(self, name, old, new):
         for k,v in iteritems(new):
             assert mime_pat.match(k)
-            nt.assert_is_instance(v, string_types)
+            assert isinstance(v, string_types)
 
 
 # shell replies
@@ -257,9 +257,9 @@ def validate_message(msg, msg_type=None, parent=None):
     """
     RMessage().check(msg)
     if msg_type:
-        nt.assert_equal(msg['msg_type'], msg_type)
+        assert msg['msg_type'] == msg_type
     if parent:
-        nt.assert_equal(msg['parent_header']['msg_id'], parent)
+        assert msg['parent_header']['msg_id'] == parent
     content = msg['content']
     ref = references[msg['msg_type']]
     ref.check(content)
@@ -286,7 +286,7 @@ def test_execute_silent():
     # flush status=idle
     status = KC.iopub_channel.get_msg(timeout=TIMEOUT)
     validate_message(status, 'status', msg_id)
-    nt.assert_equal(status['content']['execution_state'], 'idle')
+    assert status['content']['execution_state'] == 'idle'
 
     nt.assert_raises(Empty, KC.iopub_channel.get_msg, timeout=0.1)
     count = reply['execution_count']
@@ -296,19 +296,19 @@ def test_execute_silent():
     # flush status=idle
     status = KC.iopub_channel.get_msg(timeout=TIMEOUT)
     validate_message(status, 'status', msg_id)
-    nt.assert_equal(status['content']['execution_state'], 'idle')
+    assert status['content']['execution_state'] == 'idle'
 
     nt.assert_raises(Empty, KC.iopub_channel.get_msg, timeout=0.1)
     count_2 = reply['execution_count']
-    nt.assert_equal(count_2, count)
+    assert count_2 == count
 
 
 def test_execute_error():
     flush_channels()
 
     msg_id, reply = execute(code='1/0')
-    nt.assert_equal(reply['status'], 'error')
-    nt.assert_equal(reply['ename'], 'ZeroDivisionError')
+    assert reply['status'] == 'error'
+    assert reply['ename'] == 'ZeroDivisionError'
 
     error = KC.iopub_channel.get_msg(timeout=TIMEOUT)
     validate_message(error, 'error', msg_id)
@@ -325,7 +325,7 @@ def test_execute_inc():
 
     msg_id, reply = execute(code='x=2')
     count_2 = reply['execution_count']
-    nt.assert_equal(count_2, count+1)
+    assert count_2 == count+1
 
 def test_execute_stop_on_error():
     """execute request should not abort execution queue with stop_on_error False"""
@@ -341,7 +341,7 @@ def test_execute_stop_on_error():
     msg_id = KC.execute(code='print("Hello")')
     KC.get_shell_msg(timeout=TIMEOUT)
     reply = KC.get_shell_msg(timeout=TIMEOUT)
-    nt.assert_equal(reply['content']['status'], 'aborted')
+    assert reply['content']['status'] == 'aborted'
 
     flush_channels()
 
@@ -349,7 +349,7 @@ def test_execute_stop_on_error():
     msg_id = KC.execute(code='print("Hello")')
     KC.get_shell_msg(timeout=TIMEOUT)
     reply = KC.get_shell_msg(timeout=TIMEOUT)
-    nt.assert_equal(reply['content']['status'], 'ok')
+    assert reply['content']['status'] == 'ok'
 
 
 def test_user_expressions():
@@ -370,8 +370,8 @@ def test_user_expressions_fail():
     msg_id, reply = execute(code='x=0', user_expressions=dict(foo='nosuchname'))
     user_expressions = reply['user_expressions']
     foo = user_expressions['foo']
-    nt.assert_equal(foo['status'], 'error')
-    nt.assert_equal(foo['ename'], 'NameError')
+    assert foo['status'] == 'error'
+    assert foo['ename'] == 'NameError'
 
 
 def test_oinfo():
@@ -393,8 +393,8 @@ def test_oinfo_found():
     content = reply['content']
     assert content['found']
     text = content['data']['text/plain']
-    nt.assert_in('Type:', text)
-    nt.assert_in('Docstring:', text)
+    assert 'Type:' in text
+    assert 'Docstring:' in text
 
 
 def test_oinfo_detail():
@@ -408,8 +408,8 @@ def test_oinfo_detail():
     content = reply['content']
     assert content['found']
     text = content['data']['text/plain']
-    nt.assert_in('Signature:', text)
-    nt.assert_in('Source:', text)
+    assert 'Signature:' in text
+    assert 'Source:' in text
 
 
 def test_oinfo_not_found():
@@ -419,7 +419,7 @@ def test_oinfo_not_found():
     reply = KC.get_shell_msg(timeout=TIMEOUT)
     validate_message(reply, 'inspect_reply', msg_id)
     content = reply['content']
-    nt.assert_false(content['found'])
+    assert not content['found']
 
 
 def test_complete():
@@ -432,7 +432,7 @@ def test_complete():
     validate_message(reply, 'complete_reply', msg_id)
     matches = reply['content']['matches']
     for name in ('alpha', 'albert'):
-        nt.assert_in(name, matches)
+        assert name in matches
 
 
 def test_kernel_info_request():
@@ -465,11 +465,12 @@ def test_comm_info_request():
 
 def test_single_payload():
     flush_channels()
-    msg_id, reply = execute(code="for i in range(3):\n"+
-                                 "   x=range?\n")
+    msg_id, reply = execute(code="ip = get_ipython()\n"
+                                 "for i in range(3):\n"
+                                 "   ip.set_next_input('Hello There')\n")
     payload = reply['payload']
     next_input_pls = [pl for pl in payload if pl["source"] == "set_next_input"]
-    nt.assert_equal(len(next_input_pls), 1)
+    assert len(next_input_pls) == 1
 
 def test_is_complete():
     flush_channels()
@@ -488,7 +489,7 @@ def test_history_range():
     reply = KC.get_shell_msg(timeout=TIMEOUT)
     validate_message(reply, 'history_reply', msg_id)
     content = reply['content']
-    nt.assert_equal(len(content['history']), 1)
+    assert len(content['history']) == 1
 
 def test_history_tail():
     flush_channels()
@@ -500,7 +501,7 @@ def test_history_tail():
     reply = KC.get_shell_msg(timeout=TIMEOUT)
     validate_message(reply, 'history_reply', msg_id)
     content = reply['content']
-    nt.assert_equal(len(content['history']), 1)
+    assert len(content['history']) == 1
 
 def test_history_search():
     flush_channels()
@@ -512,7 +513,7 @@ def test_history_search():
     reply = KC.get_shell_msg(timeout=TIMEOUT)
     validate_message(reply, 'history_reply', msg_id)
     content = reply['content']
-    nt.assert_equal(len(content['history']), 1)
+    assert len(content['history']) == 1
 
 # IOPub channel
 
@@ -525,7 +526,7 @@ def test_stream():
     stdout = KC.iopub_channel.get_msg(timeout=TIMEOUT)
     validate_message(stdout, 'stream', msg_id)
     content = stdout['content']
-    nt.assert_equal(content['text'], u'hi\n')
+    assert content['text'] == u'hi\n'
 
 
 def test_display_data():
@@ -536,4 +537,4 @@ def test_display_data():
     display = KC.iopub_channel.get_msg(timeout=TIMEOUT)
     validate_message(display, 'display_data', parent=msg_id)
     data = display['content']['data']
-    nt.assert_equal(data['text/plain'], u'1')
+    assert data['text/plain'] == u'1'
